/* GStreamer
 * Copyright (C) 2010 Jan Schmidt <thaytan@noraisin.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GSTINTERACTBIN_H__
#define __GSTINTERACTBIN_H__

#include <gst/gst.h>

G_BEGIN_DECLS

/* #defines don't like whitespacey bits */
#define GST_TYPE_INTERACT_BIN \
  (gst_interactbin_get_type())
#define GST_INTERACTBIN(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_INTERACT_BIN,GstInteractBin))
#define GST_INTERACTBIN_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_INTERACT_BIN,GstInteractBinClass))
#define IS_GST_INTERACTBIN(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_INTERACT_BIN))
#define IS_GST_INTERACTBIN_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_INTERACT_BIN))

typedef struct _GstInteractBin      GstInteractBin;
typedef struct _GstInteractBinClass GstInteractBinClass;

#define GSTI_ELEM_SOURCE         0
#define GSTI_ELEM_MQUEUE         2
#define GSTI_ELEM_SPUQ           3
#define GSTI_ELEM_VIDDEC         4
#define GSTI_ELEM_AUDDEC         6
#define GSTI_ELEM_VIDQ           7
#define GSTI_ELEM_LAST           11

struct _GstInteractBin
{
  GstBin element;

  /* Protects pieces list and properties */
  GMutex *main_lock;
  GMutex *preroll_lock;

  gchar *location;
  gchar *last_uri;
  GstElement *pieces[GSTI_ELEM_LAST];

  GstPad *video_pad;
  GstPad *audio_pad;
  GstPad *subpicture_pad;

  gboolean video_added;
  gboolean audio_added;
  gboolean audio_broken;
  gboolean subpicture_added;

  GList *mq_req_pads;
};

struct _GstInteractBinClass 
{
  GstBinClass parent_class;
};

GType gst_interactbin_get_type (void);

G_END_DECLS

#endif /* __GSTINTERACTBIN_H__ */
