/* GStreamer
 * Copyright (C) 2008 Jan Schmidt <thaytan@noraisin.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __GST_INTERACT_SRC_H__
#define __GST_INTERACT_SRC_H__

#include <gst/gst.h>

#include <gst/base/gstbasesrc.h>
#include <librsvg/rsvg.h>
#include <librsvg/rsvg-cairo.h>

#include <stdint.h>

G_BEGIN_DECLS

#define GST_TYPE_INTERACT_SRC (gst_interact_get_type())
#define GST_INTERACT_SRC(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_INTERACT_SRC,GstInteractSrc))
#define GST_INTERACT_SRC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_INTERACT_SRC,GstInteractSrcClass))
#define IS_GST_INTERACT_SRC(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_INTERACT_SRC))
#define IS_GST_INTERACT_SRC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_INTERACT_SRC))

typedef struct _GstInteractSrc      GstInteractSrc;
typedef struct _GstInteractSrcClass GstInteractSrcClass;

typedef struct _GstInteractSlide      GstInteractSlide;
typedef struct _GstInteractButton     GstInteractButton;

struct _GstInteractSrc
{
  GstBaseSrc parent;
  gchar         *location;

  gint          frame_no;
  guint         last_time;

  GMutex	*interact_lock;
  gboolean      in_playing;
  gboolean      running;
  gboolean      was_mouse_over;

  gint          active_button;

  GstBuffer     *out_buf;
  GstBuffer     *last_buf;

  GstCaps       *cur_caps;

  gboolean      discont;
  gboolean      commands_changed;
  gboolean      need_redraw;

  GstPad        *spu_pad;

  gint          last_x, last_y;

  GArray        *slides;
  GstInteractSlide *cur_slide;
  GstInteractSlide *prev_slide;

  gint          target_w, target_h;
  gint          out_w, out_h;
  gint          full_w, full_h;
};

struct _GstInteractSrcClass 
{
  GstBaseSrcClass parent_class;
};

struct _GstInteractButton
{
  gint id;
  gint x1, y1, x2, y2;
  gchar *dest_name;
  gchar *launch_cmd;
};

struct _GstInteractSlide
{
  gchar *name;
  RsvgHandle *rsvg;
  GArray *buttons;
};

GType gst_interact_get_type (void);

gboolean slides_read(GstInteractSrc *src, const char *fname);
void    slides_free (GArray *slides);
GstInteractSlide *slides_find_slide (GstInteractSrc *src, const gchar *name);
GstInteractButton *slides_find_button (GstInteractSrc *src, GstInteractSlide *slide, gint x, gint y);

G_END_DECLS

#endif /* __GST_INTERACT_SRC_H__ */
